@@ -616,11 +616,11 @@ class TaskWorker(BaseTaskWorker):
             reason_for_incompletion = err_msg
         finally:
             task_result = ConductorTaskResult(
-                workflowInstanceId=task['workflowInstanceId'],
+                workflowInstanceId=task.get('workflowInstanceId'),
                 taskId=task['taskId'],
                 reasonForIncompletion=reason_for_incompletion,
                 callbackAfterSeconds=0,
-                workerId=task['workerId'],
+                workerId=task.get('workerId'),
                 status=status,
                 outputData=output_data,
                 outputMessage={
